<?php
/*
 * This is a "fixed" version of the ssl.php lib file
 * It resolves an issue with the port number being included in the 
 * $_SERVER['HTTP_HOST'] variable and causing an endless loop
 * when trying to access SSL pages.
 */

function NormalizeSSLSettings()
{
	// Some hosts do not set $_SERVER['HTTPS'], so the only way we can detect SSL urls is if
	// they set the SCRIPT_URI and it contains https://
	if(isset($_SERVER['SCRIPT_URI']) && substr($_SERVER['SCRIPT_URI'], 0, 8) == 'https://') {
		$_SERVER['HTTPS'] = 'on';
	}

	// Normalise $_SERVER['HTTPS']
	if(isset($_SERVER['HTTPS'])) {
		switch(strtolower($_SERVER['HTTPS'])) {
			case "true":
			case "on":
			case "1":
				$_SERVER['HTTPS'] = 'on';
				break;
			default:
				$_SERVER['HTTPS'] = 'off';
		}
	}
	else {
		$_SERVER['HTTPS'] = 'off';
	}
}

function SetupSSLOptions()
{
	// Normalize
	NormalizeSSLSettings();
	
	$ShopPath = GetConfig('ShopPath');
	$GLOBALS['ISC_CFG']['ShopPathNormal'] = $ShopPath;

	// Is SSL enabled for the checkout process? If so setup the checkout links as such
	if(GetConfig('UseSSL')) {
		// determine which url we should be on
		$ShopPathSSL = $ShopPath;

		$ShopPathSSL = str_replace("http://", "https://", $ShopPathSSL);

		// accessing securely?
		if ($_SERVER['HTTPS'] == 'on') {
			// check if we're on the correct domain for our ssl setting
			$host = '';
			if (function_exists('apache_getenv')) {
				$host = @apache_getenv('HTTP_HOST');
			}

			if (!$host) {
				$host = @$_SERVER['HTTP_HOST'];
			}

			$shop_url = parse_url($ShopPathSSL);

		     /*
              * FIX: This code uses a regular expression to take into account
              * missing www. subdomains and the appended port number if they exist.
              */
             
             $host =  $shop_url['host'].":443" == "www.".$host ? $shop_url['host'] : $host;
             
             // Use Regex to check if this is valid despite ports or lack/inclusion of www.
             $pattern = "/^(www\.)?(".$shop_url['host'].")+(:443)?$/i";
             $test = preg_match($pattern, $host, $matches);
             
             if (is_array($shop_url) && !$test) {
                // redirect if not correct host
                $location = GetLocation();
                ob_end_clean();
                header("Location: " . $ShopPathSSL . ':443/' . $location);
                exit;
             }
		}

		// Are we on a page that should use SSL?
		$ssl_pages = array (
			"account.php",
			"checkout.php",
			"eway.php",
			"login.php",
			"authorizenet.php"
		);

		$uri = explode("/", $_SERVER['PHP_SELF']);
		$page = $uri[count($uri)-1];

		if (in_array($page, $ssl_pages)) {
			$ShopPath = $ShopPathSSL;
			// If we're not accessing this page via HTTPS then we need to redirect the user to the HTTPS version
			if($_SERVER['HTTPS'] == "off" && $_SERVER['REQUEST_METHOD'] == "GET") {
				ob_end_clean();
				$location = GetLocation();

				header("Location: " . $ShopPathSSL . '/' . $location);
				exit;
			}
		}

		$GLOBALS['ISC_CFG']['ShopPathSSL'] = $ShopPathSSL;
	}
	else {
		$GLOBALS['ISC_CFG']['ShopPathSSL'] = $ShopPath;
	}

	// If we're still on a HTTPS link (maybe this page requires it for a certain checkout module)
	// override the shop path with the HTTPS version
	if($_SERVER['HTTPS'] == "on") {
		$GLOBALS['ISC_CFG']['ShopPath'] = str_replace("http://", "https://", $ShopPath);
	}

	// Now that the variables are stored in the config section, we just map them back to the existing globals we had
	$GLOBALS['ShopPath'] = GetConfig('ShopPath');
	$GLOBALS['ShopPathSSL'] = GetConfig('ShopPathSSL');
	$GLOBALS['ShopPathNormal'] = GetConfig('ShopPathNormal');
}

function GetLocation()
{
	if(isset($_SERVER['PATH_INFO']) && $_SERVER['PATH_INFO'] != '') {
		$location = $_SERVER['PATH_INFO'];
	}
	elseif(isset($_ENV['PATH_INFO']) && $_ENV['PATH_INFO'] != '') {
		$location = $_ENV['PATH_INFO'];
	}
	elseif(isset($_ENV['PHP_SELF']) && $_ENV['PHP_SELF'] != '') {
		$location = $_ENV['PHP_SELF'];
	}
	else {
		$location = $_SERVER['PHP_SELF'];
	}
	$location = basename($location);

	if(isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] != '') {
		$location .= "?".$_SERVER['QUERY_STRING'];
	}
	else if(isset($_ENV['QUERY_STRING']) && $_ENV['QUERY_STRING'] != '') {
		$location = "?".$_ENV['QUERY_STRING'];
	}

	return $location;
}
?>